@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2024  Thomas Okken
+ * Copyright (C) 2004-2025  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -65,6 +65,9 @@ int docmd_varmnu1(arg_struct *arg);
 int docmd_x2line(arg_struct *arg);
 int docmd_a2line(arg_struct *arg);
 int docmd_a2pline(arg_struct *arg);
+int docmd_lock(arg_struct *arg);
+int docmd_unlock(arg_struct *arg);
+int docmd_ident(arg_struct *arg);
 int docmd_rcomplx(arg_struct *arg);
 int docmd_pcomplx(arg_struct *arg);
 int docmd_caps(arg_struct *arg);
