@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2024  Thomas Okken
+ * Copyright (C) 2004-2025  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -58,10 +58,10 @@ const command_spec cmd_array[] =
     { /* CLX */         docmd_clx,         "CLX",                 0x00, 0x00, 0x00, 0x77,  3, ARG_NONE,   1, ALLT },
     { /* ENTER */       docmd_enter,       "ENT\305R",            0x00, 0x00, 0x00, 0x83,  5, ARG_NONE,   1, ALLT },
     { /* SWAP */        docmd_swap,        "X<>Y",                0x00, 0x00, 0x00, 0x71,  4, ARG_NONE,   2, ALLT },
-    { /* RDN */         docmd_rdn,         "R\016",               0x00, 0x00, 0x00, 0x75,  2, ARG_NONE,   0, NA_T },
+    { /* RDN */         docmd_rdn,         "R\16",                0x00, 0x00, 0x00, 0x75,  2, ARG_NONE,   0, NA_T },
     { /* CHS */         docmd_chs,         "+/-",                 0x00, 0x00, 0x00, 0x54,  3, ARG_NONE,   1, 0x0f },
-    { /* DIV */         docmd_div,         "\000",                0x00, 0x00, 0x00, 0x43,  1, ARG_NONE,   2, 0x0f },
-    { /* MUL */         docmd_mul,         "\001",                0x00, 0x00, 0x00, 0x42,  1, ARG_NONE,   2, 0x0f },
+    { /* DIV */         docmd_div,         "\0",                  0x00, 0x00, 0x00, 0x43,  1, ARG_NONE,   2, 0x0f },
+    { /* MUL */         docmd_mul,         "\1",                  0x00, 0x00, 0x00, 0x42,  1, ARG_NONE,   2, 0x0f },
     { /* SUB */         docmd_sub,         "-",                   0x00, 0x00, 0x00, 0x41,  1, ARG_NONE,   2, 0x0f },
     { /* ADD */         docmd_add,         "+",                   0x00, 0x00, 0x00, 0x40,  1, ARG_NONE,   2, 0x0f },
     { /* LASTX */       docmd_lastx,       "LASTX",               0x00, 0x00, 0x00, 0x76,  5, ARG_NONE,   0, NA_T },
@@ -85,13 +85,13 @@ const command_spec cmd_array[] =
     { /* PI */          docmd_pi,          "PI",                  0x00, 0x00, 0x00, 0x72,  2, ARG_NONE,   0, NA_T },
     { /* COMPLEX */     docmd_complex,     "C\317\315PL\305X",    0x00, 0x00, 0xa0, 0x72,  7, ARG_NONE,  -1, 0x00 },
     { /* STO */         docmd_sto,         "STO",                 0x20, 0x81, 0x00, 0x91,  3, ARG_VAR,    1, ALLT },
-    { /* STO_DIV */     docmd_sto_div,     "STO\000",             0x00, 0x85, 0x00, 0x95,  4, ARG_VAR,    1, 0x0f },
-    { /* STO_MUL */     docmd_sto_mul,     "STO\001",             0x00, 0x84, 0x00, 0x94,  4, ARG_VAR,    1, 0x0f },
+    { /* STO_DIV */     docmd_sto_div,     "STO\0",               0x00, 0x85, 0x00, 0x95,  4, ARG_VAR,    1, 0x0f },
+    { /* STO_MUL */     docmd_sto_mul,     "STO\1",               0x00, 0x84, 0x00, 0x94,  4, ARG_VAR,    1, 0x0f },
     { /* STO_SUB */     docmd_sto_sub,     "STO-",                0x00, 0x83, 0x00, 0x93,  4, ARG_VAR,    1, 0x0f },
     { /* STO_ADD */     docmd_sto_add,     "STO+",                0x00, 0x82, 0x00, 0x92,  4, ARG_VAR,    1, 0x0f },
     { /* RCL */         docmd_rcl,         "RCL",                 0x20, 0x91, 0x00, 0x90,  3, ARG_VAR,    0, NA_T },
-    { /* RCL_DIV */     docmd_rcl_div,     "RCL\000",             0x00, 0x95, 0xf2, 0xd4,  4, ARG_VAR,    1, 0x0f },
-    { /* RCL_MUL */     docmd_rcl_mul,     "RCL\001",             0x00, 0x94, 0xf2, 0xd3,  4, ARG_VAR,    1, 0x0f },
+    { /* RCL_DIV */     docmd_rcl_div,     "RCL\0",               0x00, 0x95, 0xf2, 0xd4,  4, ARG_VAR,    1, 0x0f },
+    { /* RCL_MUL */     docmd_rcl_mul,     "RCL\1",               0x00, 0x94, 0xf2, 0xd3,  4, ARG_VAR,    1, 0x0f },
     { /* RCL_SUB */     docmd_rcl_sub,     "RCL-",                0x00, 0x93, 0xf2, 0xd2,  4, ARG_VAR,    1, 0x0f },
     { /* RCL_ADD */     docmd_rcl_add,     "RCL+",                0x00, 0x92, 0xf2, 0xd1,  4, ARG_VAR,    1, 0x0f },
     { /* FIX */         docmd_fix,         "FIX",                 0x20, 0xd4, 0x00, 0x9c,  3, ARG_NUM11,  0, NA_T },
@@ -115,7 +115,7 @@ const command_spec cmd_array[] =
     { /* LCLBL */       docmd_lclbl,       "LCLBL",               0x00, 0x00, 0xa2, 0x64,  5, ARG_NONE,   0, NA_T },
     { /* RDXDOT */      docmd_rdxdot,      "RDX.",                0x00, 0x00, 0xa2, 0x5b,  4, ARG_NONE,   0, NA_T },
     { /* RDXCOMMA */    docmd_rdxcomma,    "RDX,",                0x00, 0x00, 0xa2, 0x5c,  4, ARG_NONE,   0, NA_T },
-    { /* CLSIGMA */     docmd_clsigma,     "CL\005",              0x00, 0x00, 0x00, 0x70,  3, ARG_NONE,   0, NA_T },
+    { /* CLSIGMA */     docmd_clsigma,     "CL\5",                0x00, 0x00, 0x00, 0x70,  3, ARG_NONE,   0, NA_T },
     { /* CLP */         docmd_clp,         "CLP",                 0x00, 0xf0, 0x00, 0x00,  3, ARG_PRGM,   0, NA_T },
     { /* CLV */         docmd_clv,         "CLV",                 0x00, 0xb0, 0xf2, 0xd8,  3, ARG_NAMED,  0, NA_T },
     { /* CLST */        docmd_clst,        "CLST",                0x00, 0x00, 0x00, 0x73,  4, ARG_NONE,   0, NA_T },
@@ -125,12 +125,12 @@ const command_spec cmd_array[] =
     { /* CLLCD */       docmd_cllcd,       "CLLCD",               0x00, 0x00, 0xa7, 0x63,  5, ARG_NONE,   0, NA_T },
     { /* CLMENU */      docmd_clmenu,      "CLM\305N\325",        0x00, 0x00, 0xa2, 0x6d,  6, ARG_NONE,   0, NA_T },
     { /* CLALLa */      NULL,              "CLALL",               0x42, 0x00, 0x00, 0x00,  5, ARG_NONE,   0, NA_T },
-    { /* TO_DEG */      docmd_to_deg,      "\017DEG",             0x00, 0x00, 0x00, 0x6b,  4, ARG_NONE,   1, 0x05 },
-    { /* TO_RAD */      docmd_to_rad,      "\017RAD",             0x00, 0x00, 0x00, 0x6a,  4, ARG_NONE,   1, 0x05 },
-    { /* TO_HR */       docmd_to_hr,       "\017HR",              0x00, 0x00, 0x00, 0x6d,  3, ARG_NONE,   1, 0x05 },
-    { /* TO_HMS */      docmd_to_hms,      "\017HMS",             0x00, 0x00, 0x00, 0x6c,  4, ARG_NONE,   1, 0x05 },
-    { /* TO_REC */      docmd_to_rec,      "\017REC",             0x00, 0x00, 0x00, 0x4e,  4, ARG_NONE,  -1, 0x00 },
-    { /* TO_POL */      docmd_to_pol,      "\017POL",             0x00, 0x00, 0x00, 0x4f,  4, ARG_NONE,  -1, 0x00 },
+    { /* TO_DEG */      docmd_to_deg,      "\17DEG",              0x00, 0x00, 0x00, 0x6b,  4, ARG_NONE,   1, 0x05 },
+    { /* TO_RAD */      docmd_to_rad,      "\17RAD",              0x00, 0x00, 0x00, 0x6a,  4, ARG_NONE,   1, 0x05 },
+    { /* TO_HR */       docmd_to_hr,       "\17HR",               0x00, 0x00, 0x00, 0x6d,  3, ARG_NONE,   1, 0x05 },
+    { /* TO_HMS */      docmd_to_hms,      "\17HMS",              0x00, 0x00, 0x00, 0x6c,  4, ARG_NONE,   1, 0x05 },
+    { /* TO_REC */      docmd_to_rec,      "\17REC",              0x00, 0x00, 0x00, 0x4e,  4, ARG_NONE,  -1, 0x00 },
+    { /* TO_POL */      docmd_to_pol,      "\17POL",              0x00, 0x00, 0x00, 0x4f,  4, ARG_NONE,  -1, 0x00 },
     { /* IP */          docmd_ip,          "IP",                  0x00, 0x00, 0x00, 0x68,  2, ARG_NONE,   1, 0x05 },
     { /* FP */          docmd_fp,          "FP",                  0x00, 0x00, 0x00, 0x69,  2, ARG_NONE,   1, 0x05 },
     { /* RND */         docmd_rnd,         "RND",                 0x00, 0x00, 0x00, 0x6e,  3, ARG_NONE,   1, 0x0f },
@@ -178,12 +178,12 @@ const command_spec cmd_array[] =
     { /* X_LE_0 */      docmd_x_le_0,      "X\0110?",             0x00, 0x00, 0x00, 0x7b,  4, ARG_NONE,   1, 0x01 },
     { /* X_GE_0 */      docmd_x_ge_0,      "X\0130?",             0x00, 0x00, 0xa2, 0x5f,  4, ARG_NONE,   1, 0x01 },
     { /* X_EQ_Y */      docmd_x_eq_y,      "X=Y?",                0x00, 0x00, 0x00, 0x78,  4, ARG_NONE,   2, ALLT },
-    { /* X_NE_Y */      docmd_x_ne_y,      "X\014Y?",             0x00, 0x00, 0x00, 0x79,  4, ARG_NONE,   2, ALLT },
+    { /* X_NE_Y */      docmd_x_ne_y,      "X\14Y?",              0x00, 0x00, 0x00, 0x79,  4, ARG_NONE,   2, ALLT },
     { /* X_LT_Y */      docmd_x_lt_y,      "X<Y?",                0x00, 0x00, 0x00, 0x44,  4, ARG_NONE,   2, 0x01 },
     { /* X_GT_Y */      docmd_x_gt_y,      "X>Y?",                0x00, 0x00, 0x00, 0x45,  4, ARG_NONE,   2, 0x01 },
-    { /* X_LE_Y */      docmd_x_le_y,      "X\011Y?",             0x00, 0x00, 0x00, 0x46,  4, ARG_NONE,   2, 0x01 },
-    { /* X_GE_Y */      docmd_x_ge_y,      "X\013Y?",             0x00, 0x00, 0xa2, 0x60,  4, ARG_NONE,   2, 0x01 },
-    { /* PRSIGMA */     docmd_prsigma,     "PR\005",              0x00, 0x00, 0xa7, 0x52,  3, ARG_NONE,   0, NA_T },
+    { /* X_LE_Y */      docmd_x_le_y,      "X\11Y?",              0x00, 0x00, 0x00, 0x46,  4, ARG_NONE,   2, 0x01 },
+    { /* X_GE_Y */      docmd_x_ge_y,      "X\13Y?",              0x00, 0x00, 0xa2, 0x60,  4, ARG_NONE,   2, 0x01 },
+    { /* PRSIGMA */     docmd_prsigma,     "PR\5",                0x00, 0x00, 0xa7, 0x52,  3, ARG_NONE,   0, NA_T },
     { /* PRP */         docmd_prp,         "PRP",                 0x42, 0x00, 0x00, 0x00,  3, ARG_PRGM,   0, NA_T },
     { /* PRV */         docmd_prv,         "PRV",                 0x00, 0xb1, 0xf2, 0xd9,  3, ARG_NAMED,  0, NA_T },
     { /* PRSTK */       docmd_prstk,       "PRST\313",            0x00, 0x00, 0xa7, 0x53,  5, ARG_NONE,   0, NA_T },
@@ -199,8 +199,8 @@ const command_spec cmd_array[] =
     { /* MAN */         docmd_man,         "MAN",                 0x00, 0x00, 0xa7, 0x5b,  3, ARG_NONE,   0, NA_T },
     { /* NORM */        docmd_norm,        "NORM",                0x00, 0x00, 0xa7, 0x5c,  4, ARG_NONE,   0, NA_T },
     { /* TRACE */       docmd_trace,       "TRACE",               0x00, 0x00, 0xa7, 0x5d,  5, ARG_NONE,   0, NA_T },
-    { /* SIGMAADD */    docmd_sigmaadd,    "\005+",               0x00, 0x00, 0x00, 0x47,  2, ARG_NONE,   1, 0x05 },
-    { /* SIGMASUB */    docmd_sigmasub,    "\005-",               0x00, 0x00, 0x00, 0x48,  2, ARG_NONE,   1, 0x05 },
+    { /* SIGMAADD */    docmd_sigmaadd,    "\5+",                 0x00, 0x00, 0x00, 0x47,  2, ARG_NONE,   1, 0x05 },
+    { /* SIGMASUB */    docmd_sigmasub,    "\5-",                 0x00, 0x00, 0x00, 0x48,  2, ARG_NONE,   1, 0x05 },
     { /* GTO */         docmd_gto,         "GTO",                 0x20, 0xa6, 0x00, 0x00,  3, ARG_LBL,    0, NA_T },
     { /* END */         docmd_rtn,         "END",                 0x20, 0x00, 0x00, 0x00,  3, ARG_NONE,   0, NA_T },
     { /* NUMBER */      docmd_number,      "",                    0x24, 0x00, 0x00, 0x00,  0, ARG_NONE,   0, NA_T },
@@ -259,12 +259,12 @@ const command_spec cmd_array[] =
     { /* KEY9X */       docmd_key9x,       "KEY 9 XEQ",           0x24, 0x00, 0x00, 0x00,  9, ARG_LBL,    0, NA_T },
     { /* VMEXEC */      NULL,              "",                    0x44, 0x00, 0x00, 0x00,  0, ARG_OTHER,  0, NA_T },
     { /* VMSTO */       docmd_vmsto,       "STO",                 0x44, 0x00, 0x00, 0x00,  3, ARG_OTHER,  1, ALLT },
-    { /* SIGMAREG */    docmd_sigma_reg,   "\005REG",             0x00, 0xd3, 0x00, 0x99,  4, ARG_NUM99,  0, NA_T },
-    { /* SIGMAREG_T */  docmd_sigma_reg_t, "\005R\305G?",         0x00, 0x00, 0xa6, 0x78,  5, ARG_NONE,   0, NA_T },
+    { /* SIGMAREG */    docmd_sigma_reg,   "\5REG",               0x00, 0xd3, 0x00, 0x99,  4, ARG_NUM99,  0, NA_T },
+    { /* SIGMAREG_T */  docmd_sigma_reg_t, "\5R\305G?",           0x00, 0x00, 0xa6, 0x78,  5, ARG_NONE,   0, NA_T },
     { /* CLD */         docmd_cld,         "CLD",                 0x00, 0x00, 0x00, 0x7f,  3, ARG_NONE,   0, NA_T },
     { /* ACOSH */       docmd_acosh,       "ACOSH",               0x00, 0x00, 0xa0, 0x66,  5, ARG_NONE,   1, 0x0f },
     { /* ALENG */       docmd_aleng,       "ALEN\307",            0x00, 0x00, 0xa6, 0x41,  5, ARG_NONE,   0, NA_T },
-    { /* ALLSIGMA */    docmd_allsigma,    "ALL\005",             0x00, 0x00, 0xa0, 0xae,  4, ARG_NONE,   0, NA_T },
+    { /* ALLSIGMA */    docmd_allsigma,    "ALL\5",               0x00, 0x00, 0xa0, 0xae,  4, ARG_NONE,   0, NA_T },
     { /* AND */         docmd_and,         "AND",                 0x00, 0x00, 0xa5, 0x88,  3, ARG_NONE,   2, 0x01 },
     { /* AOFF */        docmd_aoff,        "AOFF",                0x00, 0x00, 0x00, 0x8b,  4, ARG_NONE,   0, NA_T },
     { /* AON */         docmd_aon,         "AON",                 0x00, 0x00, 0x00, 0x8c,  3, ARG_NONE,   0, NA_T },
@@ -275,8 +275,8 @@ const command_spec cmd_array[] =
     { /* ATOX */        docmd_atox,        "ATOX",                0x00, 0x00, 0xa6, 0x47,  4, ARG_NONE,   0, NA_T },
     { /* BASEADD */     docmd_baseadd,     "BASE+",               0x00, 0x00, 0xa0, 0xe6,  5, ARG_NONE,   2, 0x01 },
     { /* BASESUB */     docmd_basesub,     "BASE-",               0x00, 0x00, 0xa0, 0xe7,  5, ARG_NONE,   2, 0x01 },
-    { /* BASEMUL */     docmd_basemul,     "BASE\001",            0x00, 0x00, 0xa0, 0xe8,  5, ARG_NONE,   2, 0x01 },
-    { /* BASEDIV */     docmd_basediv,     "BASE\000",            0x00, 0x00, 0xa0, 0xe9,  5, ARG_NONE,   2, 0x01 },
+    { /* BASEMUL */     docmd_basemul,     "BASE\1",              0x00, 0x00, 0xa0, 0xe8,  5, ARG_NONE,   2, 0x01 },
+    { /* BASEDIV */     docmd_basediv,     "BASE\0",              0x00, 0x00, 0xa0, 0xe9,  5, ARG_NONE,   2, 0x01 },
     { /* BASECHS */     docmd_basechs,     "B\301\323\305+/-",    0x00, 0x00, 0xa0, 0xea,  7, ARG_NONE,   1, 0x01 },
     { /* BEST */        docmd_best,        "BEST",                0x00, 0x00, 0xa0, 0x9f,  4, ARG_NONE,   0, NA_T },
     { /* BINM */        docmd_binm,        "BINM",                0x00, 0x00, 0xa0, 0xe5,  4, ARG_NONE,   0, NA_T },
@@ -313,7 +313,7 @@ const command_spec cmd_array[] =
     { /* J_ADD */       docmd_j_add,       "J+",                  0x00, 0x00, 0xa6, 0xd4,  2, ARG_NONE,   0, NA_T },
     { /* J_SUB */       docmd_j_sub,       "J-",                  0x00, 0x00, 0xa6, 0xd5,  2, ARG_NONE,   0, NA_T },
     { /* LINF */        docmd_linf,        "LINF",                0x00, 0x00, 0xa0, 0xa1,  4, ARG_NONE,   0, NA_T },
-    { /* LINSIGMA */    docmd_linsigma,    "LIN\005",             0x00, 0x00, 0xa0, 0xad,  4, ARG_NONE,   0, NA_T },
+    { /* LINSIGMA */    docmd_linsigma,    "LIN\5",               0x00, 0x00, 0xa0, 0xad,  4, ARG_NONE,   0, NA_T },
     { /* LN_1_X */      docmd_ln_1_x,      "LN1+\330",            0x00, 0x00, 0x00, 0x65,  5, ARG_NONE,   1, 0x05 },
     { /* LOGF */        docmd_logf,        "LOGF",                0x00, 0x00, 0xa0, 0xa2,  4, ARG_NONE,   0, NA_T },
     { /* MEAN */        docmd_mean,        "MEAN",                0x00, 0x00, 0x00, 0x7c,  4, ARG_NONE,   0, NA_T },
@@ -347,12 +347,12 @@ const command_spec cmd_array[] =
     { /* X_SWAP */      docmd_x_swap,      "X<>",                 0x00, 0x86, 0x00, 0xce,  3, ARG_VAR,    1, ALLT },
     { /* XOR */         docmd_xor,         "XOR",                 0x00, 0x00, 0xa5, 0x8a,  3, ARG_NONE,   2, 0x01 },
     { /* YINT */        docmd_yint,        "YINT",                0x00, 0x00, 0xa0, 0xa6,  4, ARG_NONE,   0, NA_T },
-    { /* TO_DEC */      docmd_to_dec,      "\017DEC",             0x00, 0x00, 0x00, 0x5f,  4, ARG_NONE,   1, 0x01 },
-    { /* TO_OCT */      docmd_to_oct,      "\017OCT",             0x00, 0x00, 0x00, 0x6f,  4, ARG_NONE,   1, 0x01 },
-    { /* LEFT */        docmd_left,        "\020",                0x00, 0x00, 0xa6, 0xdc,  1, ARG_NONE,   0, FUNC },
+    { /* TO_DEC */      docmd_to_dec,      "\17DEC",              0x00, 0x00, 0x00, 0x5f,  4, ARG_NONE,   1, 0x01 },
+    { /* TO_OCT */      docmd_to_oct,      "\17OCT",              0x00, 0x00, 0x00, 0x6f,  4, ARG_NONE,   1, 0x01 },
+    { /* LEFT */        docmd_left,        "\20",                 0x00, 0x00, 0xa6, 0xdc,  1, ARG_NONE,   0, FUNC },
     { /* UP */          docmd_up,          "^",                   0x00, 0x00, 0xa6, 0xde,  1, ARG_NONE,   0, FUNC },
-    { /* DOWN */        docmd_down,        "\016",                0x00, 0x00, 0xa6, 0xdf,  1, ARG_NONE,   0, FUNC },
-    { /* RIGHT */       docmd_right,       "\017",                0x00, 0x00, 0xa6, 0xdd,  1, ARG_NONE,   0, FUNC },
+    { /* DOWN */        docmd_down,        "\16",                 0x00, 0x00, 0xa6, 0xdf,  1, ARG_NONE,   0, FUNC },
+    { /* RIGHT */       docmd_right,       "\17",                 0x00, 0x00, 0xa6, 0xdd,  1, ARG_NONE,   0, FUNC },
     { /* PERCENT_CH */  docmd_percent_ch,  "%CH",                 0x00, 0x00, 0x00, 0x4d,  3, ARG_NONE,   2, 0x01 },
     { /* SIMQ */        docmd_simq,        "SIMQ",                0x4c, 0x00, 0x00, 0x00,  4, ARG_COUNT,  0, NA_T },
     { /* MATA */        docmd_mata,        "MATA",                0x4c, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
@@ -398,7 +398,7 @@ const command_spec cmd_array[] =
     /* Programming */
     { /* LSTO */        docmd_lsto,        "LSTO",                0x00, 0xc7, 0xf2, 0xed,  4, ARG_NAMED,  1, ALLT },
     { /* SST_UP */      NULL,              "SST^",                0x40, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
-    { /* SST_RT */      NULL,              "SST\017",             0x40, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
+    { /* SST_RT */      NULL,              "SST\17",              0x40, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
     { /* WSIZE */       docmd_wsize,       "WSIZE",               0x00, 0x00, 0xa7, 0xd3,  5, ARG_NONE,   1, 0x01 },
     { /* WSIZE_T */     docmd_wsize_t,     "WS\311Z\305?",        0x00, 0x00, 0xa7, 0xd4,  6, ARG_NONE,   0, NA_T },
     { /* YMD */         docmd_ymd,         "YMD",                 0x00, 0x00, 0xa7, 0xd5,  3, ARG_NONE,   0, NA_T },
@@ -437,7 +437,7 @@ const command_spec cmd_array[] =
     { /* DUPN */        docmd_dupn,        "DUPN",                0x00, 0xf2, 0xf2, 0xa2,  4, ARG_NUM9,   0, NA_T },
     { /* PICK */        docmd_pick,        "PICK",                0x00, 0xf3, 0xf2, 0xa3,  4, ARG_NUM9,   0, NA_T },
     { /* UNPICK */      docmd_unpick,      "UNPICK",              0x00, 0xf4, 0xf2, 0xa4,  6, ARG_NUM9,   0, NA_T },
-    { /* RDNN */        docmd_rdnn,        "R\016N",              0x00, 0xf6, 0xf2, 0xa5,  3, ARG_NUM9,   0, NA_T },
+    { /* RDNN */        docmd_rdnn,        "R\16N",               0x00, 0xf6, 0xf2, 0xa5,  3, ARG_NUM9,   0, NA_T },
     { /* RUPN */        docmd_rupn,        "R^N",                 0x00, 0xf7, 0xf2, 0xa6,  3, ARG_NUM9,   0, NA_T },
 
     /* Miscellaneous */
@@ -467,6 +467,9 @@ const command_spec cmd_array[] =
     { /* PUTMI */       docmd_putmi,       "PUTMI",               0x00, 0x73, 0xf2, 0x66,  5, ARG_M_STK,  3, 0x13 },
     { /* GETLI */       docmd_getli,       "GETLI",               0x00, 0x74, 0xf2, 0x67,  5, ARG_L_STK,  1, 0x01 },
     { /* PUTLI */       docmd_putli,       "PUTLI",               0x00, 0x75, 0xf2, 0x68,  5, ARG_L_STK,  2, ALLT },
+    { /* LOCK */        docmd_lock,        "LOCK",                0x42, 0x00, 0x00, 0x00,  4, ARG_NONE,   0, NA_T },
+    { /* UNLOCK */      docmd_unlock,      "UNL\317\303K",        0x42, 0x00, 0x00, 0x00,  6, ARG_NONE,   0, NA_T },
+    { /* IDENT */       docmd_ident,       "IDENT",               0x00, 0x00, 0xa7, 0xf5,  5, ARG_NONE,   0, NA_T },
 
     /* String & List Functions */
     { /* XSTR */        docmd_xstr,        "XSTR",                0x20, 0x41, 0x00, 0x00,  4, ARG_XSTR,   0, NA_T },
@@ -480,29 +483,29 @@ const command_spec cmd_array[] =
     { /* HEAD */        docmd_head,        "HEAD",                0x00, 0x03, 0xf2, 0x13,  4, ARG_VAR,    0, NA_T },
     { /* REV */         docmd_rev,         "REV",                 0x00, 0x00, 0xa7, 0xed,  3, ARG_NONE,   1, 0x30 },
     { /* POS */         docmd_pos,         "POS",                 0x00, 0x00, 0xa7, 0xee,  3, ARG_NONE,   2, FUNC },
-    { /* S_TO_N */      docmd_s_to_n,      "S\017N",              0x00, 0x00, 0xa7, 0xef,  3, ARG_NONE,   1, 0x10 },
-    { /* N_TO_S */      docmd_n_to_s,      "N\017S",              0x00, 0x00, 0xa7, 0xf0,  3, ARG_NONE,   1, ALLT },
-    { /* NN_TO_S */     docmd_nn_to_s,     "NN\017S",             0x00, 0x00, 0xa7, 0x1d,  4, ARG_NONE,   1, ALLT },
-    { /* C_TO_N */      docmd_c_to_n,      "C\017N",              0x00, 0x00, 0xa7, 0xf1,  3, ARG_NONE,   1, 0x10 },
-    { /* N_TO_C */      docmd_n_to_c,      "N\017C",              0x00, 0x00, 0xa7, 0xf2,  3, ARG_NONE,   1, 0x01 },
+    { /* S_TO_N */      docmd_s_to_n,      "S\17N",               0x00, 0x00, 0xa7, 0xef,  3, ARG_NONE,   1, 0x10 },
+    { /* N_TO_S */      docmd_n_to_s,      "N\17S",               0x00, 0x00, 0xa7, 0xf0,  3, ARG_NONE,   1, ALLT },
+    { /* NN_TO_S */     docmd_nn_to_s,     "NN\17S",              0x00, 0x00, 0xa7, 0x1d,  4, ARG_NONE,   1, ALLT },
+    { /* C_TO_N */      docmd_c_to_n,      "C\17N",               0x00, 0x00, 0xa7, 0xf1,  3, ARG_NONE,   1, 0x10 },
+    { /* N_TO_C */      docmd_n_to_c,      "N\17C",               0x00, 0x00, 0xa7, 0xf2,  3, ARG_NONE,   1, 0x01 },
     { /* LIST_T */      docmd_list_t,      "LIST?",               0x00, 0x00, 0xa7, 0xf3,  5, ARG_NONE,   1, ALLT },
     { /* NEWLIST */     docmd_newlist,     "NEWLIST",             0x00, 0x00, 0xa7, 0xf4,  7, ARG_NONE,   0, NA_T },
-    { /* TO_LIST */     docmd_to_list,     "\017LIST",            0x00, 0x00, 0xa6, 0xfc,  5, ARG_NONE,   1, 0x01 },
-    { /* FROM_LIST */   docmd_from_list,   "LIST\017",            0x00, 0x00, 0xa6, 0xfd,  5, ARG_NONE,   1, 0x20 },
+    { /* TO_LIST */     docmd_to_list,     "\17LIST",             0x00, 0x00, 0xa6, 0xfc,  5, ARG_NONE,   1, 0x01 },
+    { /* FROM_LIST */   docmd_from_list,   "LIST\17",             0x00, 0x00, 0xa6, 0xfd,  5, ARG_NONE,   1, 0x20 },
 
     /* Generalized Comparisons */
     { /* X_EQ_NN */     docmd_x_eq_nn,     "X=?",                 0x00, 0x04, 0xf2, 0x14,  3, ARG_VAR,    1, ALLT },
-    { /* X_NE_NN */     docmd_x_ne_nn,     "X\014?",              0x00, 0x05, 0xf2, 0x15,  3, ARG_VAR,    1, ALLT },
+    { /* X_NE_NN */     docmd_x_ne_nn,     "X\14?",               0x00, 0x05, 0xf2, 0x15,  3, ARG_VAR,    1, ALLT },
     { /* X_LT_NN */     docmd_x_lt_nn,     "X<?",                 0x00, 0x06, 0xf2, 0x16,  3, ARG_VAR,    1, 0x01 },
     { /* X_GT_NN */     docmd_x_gt_nn,     "X>?",                 0x00, 0x07, 0xf2, 0x17,  3, ARG_VAR,    1, 0x01 },
-    { /* X_LE_NN */     docmd_x_le_nn,     "X\011?",              0x00, 0x20, 0xf2, 0x18,  3, ARG_VAR,    1, 0x01 },
-    { /* X_GE_NN */     docmd_x_ge_nn,     "X\013?",              0x00, 0x21, 0xf2, 0x19,  3, ARG_VAR,    1, 0x01 },
+    { /* X_LE_NN */     docmd_x_le_nn,     "X\11?",               0x00, 0x20, 0xf2, 0x18,  3, ARG_VAR,    1, 0x01 },
+    { /* X_GE_NN */     docmd_x_ge_nn,     "X\13?",               0x00, 0x21, 0xf2, 0x19,  3, ARG_VAR,    1, 0x01 },
     { /* 0_EQ_NN */     docmd_0_eq_nn,     "0=?",                 0x00, 0x22, 0xf2, 0x1a,  3, ARG_VAR,    0, NA_T },
-    { /* 0_NE_NN */     docmd_0_ne_nn,     "0\014?",              0x00, 0x23, 0xf2, 0x1b,  3, ARG_VAR,    0, NA_T },
+    { /* 0_NE_NN */     docmd_0_ne_nn,     "0\14?",               0x00, 0x23, 0xf2, 0x1b,  3, ARG_VAR,    0, NA_T },
     { /* 0_LT_NN */     docmd_0_lt_nn,     "0<?",                 0x00, 0x24, 0xf2, 0x1c,  3, ARG_VAR,    0, NA_T },
     { /* 0_GT_NN */     docmd_0_gt_nn,     "0>?",                 0x00, 0x25, 0xf2, 0x1d,  3, ARG_VAR,    0, NA_T },
-    { /* 0_LE_NN */     docmd_0_le_nn,     "0\011?",              0x00, 0x26, 0xf2, 0x1e,  3, ARG_VAR,    0, NA_T },
-    { /* 0_GE_NN */     docmd_0_ge_nn,     "0\013?",              0x00, 0x27, 0xf2, 0x1f,  3, ARG_VAR,    0, NA_T },
+    { /* 0_LE_NN */     docmd_0_le_nn,     "0\11?",               0x00, 0x26, 0xf2, 0x1e,  3, ARG_VAR,    0, NA_T },
+    { /* 0_GE_NN */     docmd_0_ge_nn,     "0\13?",               0x00, 0x27, 0xf2, 0x1f,  3, ARG_VAR,    0, NA_T },
 
     /* For Plus42 Compatibility */
     { /* WIDTH */       docmd_width,       "WIDTH",               0x00, 0x00, 0xa2, 0x72,  5, ARG_NONE,   0, NA_T },
